@@ -134,10 +134,17 @@ class CommunityMember(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
+        unique_together = ['user', 'community']
         container_path = "community-members/"
         serializer_fields = ['@id', 'community', 'user', 'is_admin']
         rdf_type = "as:items"
 
+    def save(self, *args, **kwargs):
+        if not self.pk and CommunityMember.objects.filter(community=self.community, user=self.user).exists():
+            return
+
+        super(CommunityMember, self).save(*args, **kwargs)
+
 class CommunityCircle(Model):
     community = models.ForeignKey(Community, on_delete=models.CASCADE, related_name='circles', null=True, blank=True)
     circle = models.OneToOneField(Circle, on_delete=models.CASCADE, related_name="community", null=True, blank=True)
@@ -155,10 +162,17 @@ class CommunityCircle(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
+        unique_together = ['circle', 'community']
         container_path = "community-circles/"
         serializer_fields = ['@id', 'community', 'circle']
         rdf_type = "as:items"
 
+    def save(self, *args, **kwargs):
+        if not self.pk and CommunityCircle.objects.filter(community=self.community, circle=self.circle).exists():
+            return
+
+        super(CommunityCircle, self).save(*args, **kwargs)
+
 class CommunityProject(Model):
     community = models.ForeignKey(Community, on_delete=models.CASCADE, related_name='projects', null=True, blank=True)
     project = models.OneToOneField(Project, on_delete=models.CASCADE, related_name="community", null=True, blank=True)
@@ -176,10 +190,17 @@ class CommunityProject(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
+        unique_together = ['project', 'community']
         container_path = "community-projects/"
         serializer_fields = ['@id', 'community', 'project']
         rdf_type = "as:items"
 
+    def save(self, *args, **kwargs):
+        if not self.pk and CommunityProject.objects.filter(community=self.community, project=self.project).exists():
+            return
+
+        super(CommunityProject, self).save(*args, **kwargs)
+
 class CommunityJobOffer(Model):
     community = models.ForeignKey(Community, on_delete=models.CASCADE, related_name='joboffers', null=True, blank=True)
     joboffer = models.OneToOneField(JobOffer, on_delete=models.CASCADE, related_name="community", null=True, blank=True)
@@ -197,10 +218,17 @@ class CommunityJobOffer(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
+        unique_together = ['joboffer', 'community']
         container_path = "community-joboffers/"
         serializer_fields = ['@id', 'community', 'joboffer']
         rdf_type = "as:items"
 
+    def save(self, *args, **kwargs):
+        if not self.pk and CommunityJobOffer.objects.filter(community=self.community, joboffer=self.joboffer).exists():
+            return
+
+        super(CommunityJobOffer, self).save(*args, **kwargs)
+
 @receiver(pre_save, sender=Community)
 def pre_create_account(sender, instance, **kwargs):
     if not instance.urlid or instance.urlid.startswith(settings.SITE_URL):
